Hello world program to test uploading a package to PyPi.

This package contains a simple program that runs OCR on an input image.
The OCR is powered by pytesseract which works well for structured text such as webpages or book scans,
but is not very reliable for detecting text in images that are unstructured such as words on a t-shirt 
or text on MRIs.


